@@ -52,6 +52,19 @@ class MarkRadiusLineEdit(QtWidgets.QLineEdit):
             )
 
 
+class PickNPointsLineEdit(QtWidgets.QLineEdit):
+    def enterEvent(self, e):
+        if self.window().showhelp is True:
+            QtWidgets.QToolTip.showText(
+                e.globalPos(),
+                "<h3>Number of points to pick</h3>"
+                "Set the number of nearest datapoints to select "
+                "when executing 'pick' callbacks<p>"
+                "NOTE: If multiple datasets are present on a layer, this is "
+                "assigned for each dataset individually!)",
+            )
+
+
 class MarkPickButton(QtWidgets.QPushButton):
     def enterEvent(self, e):
         if self.window().showhelp is True:
@@ -167,11 +180,16 @@ class ClickCallbacks(QtWidgets.QFrame):
                 fc="none",
                 ec="r",
                 n=100,
-                zorder=998,
+                # zorder=998,
             ),
-            mark_pick=dict(fc="none", ec="r", n=100, lw=2, zorder=998),
-            annotate=dict(zorder=999),
-            annotate_pick=dict(zorder=999),
+            mark_pick=dict(
+                fc="none",
+                ec="r",
+                n=100,
+                lw=2,  # zorder=998
+            ),
+            annotate=dict(),  # zorder=999
+            annotate_pick=dict(),  # zorder=999
         )
 
         self.buttons = dict()
@@ -179,6 +197,15 @@ class ClickCallbacks(QtWidgets.QFrame):
         self.t_click = QtWidgets.QLabel("<b>Click</b> callbacks:")
         self.t_pick = QtWidgets.QLabel("<b>Pick</b> callbacks:")
 
+        # number of points to pick
+        # (init before pick map dropdown to update n)
+        self.n_points_inp = PickNPointsLineEdit()
+        self.n_points_inp.setText(str(self._pick_map.cb.pick._n_ids))
+        self.n_points_inp.setMaximumWidth(30)
+        validator = QtGui.QIntValidator()
+        self.n_points_inp.setValidator(validator)
+        self.n_points_inp.textChanged.connect(self.n_points_changed)
+
         # pick-map dropdown
         self.map_dropdown = PickMapDropdown()
         self.populate_dropdown()
@@ -189,6 +216,7 @@ class ClickCallbacks(QtWidgets.QFrame):
         dropdown_layout = QtWidgets.QHBoxLayout()
         dropdown_layout.addWidget(t_dropdown)
         dropdown_layout.addWidget(self.map_dropdown)
+        dropdown_layout.addWidget(self.n_points_inp)
 
         # Annotate
         b_ann = AnnotateButton("Annotate")
@@ -287,6 +315,7 @@ class ClickCallbacks(QtWidgets.QFrame):
                 and m.ax == self.m.ax
                 and m.layer
                 in (
+                    "all",
                     m.BM._bg_layer,
                     *m.BM._bg_layer.split("|"),
                 )
@@ -351,6 +380,11 @@ class ClickCallbacks(QtWidgets.QFrame):
 
         self._pick_map = self.map_dropdown.itemData(index)
         self.reattach_pick_callbacks()
+
+        # update number of picked points to reflect value of selected dataset
+        self.n_points_inp.setText(str(self._pick_map.cb.pick._n_ids))
+        self.n_points_changed()
+
         self.update_buttons()
 
     def on_layer_change(self, *args, **kwargs):
@@ -390,9 +424,14 @@ class ClickCallbacks(QtWidgets.QFrame):
         if mcid is not None:
             m, cid = mcid
             if key.endswith("_pick"):
-                m.cb.pick.remove(cid)
+                # explicitly check if the callback is attached to avoid warnings if
+                # the figure is closed while a callback is still attached
+                # (this way cleanup might have already removed the callback)
+                if cid in m.cb.pick.get.attached_callbacks:
+                    m.cb.pick.remove(cid)
             else:
-                m.cb.click.remove(cid)
+                if cid in m.cb.click.get.attached_callbacks:
+                    m.cb.click.remove(cid)
         self.cids[key] = None
 
         self.m.BM.update()
@@ -440,6 +479,17 @@ class ClickCallbacks(QtWidgets.QFrame):
         self.attach_callback("mark")
         self.update_buttons()
 
+    @pyqtSlot()
+    def n_points_changed(self):
+        try:
+            n = int(self.n_points_inp.text())
+        except ValueError:
+            return
+
+        self._pick_map.cb.pick.set_props(n)
+
+        self.update_buttons()
+
     def button_clicked(self, key):
         @pyqtSlot()
         def cb():
