@@ -351,7 +351,7 @@ class ScaleBar:
 
         if hasattr(self, "_lon") and hasattr(self, "_lat"):
             self.set_position()
-            self._m.BM.blit_artists(self._artists.values())
+            self._m.BM.update(artists=self._artists.values())
 
     def set_patch_props(self, offsets=None, **kwargs):
         """
@@ -390,7 +390,7 @@ class ScaleBar:
 
         if hasattr(self, "_lon") and hasattr(self, "_lat"):
             self.set_position()
-            self._m.BM.blit_artists(self._artists.values())
+            self._m.BM.update(artists=self._artists.values())
 
     def set_label_props(
         self, scale=None, rotation=None, every=None, offset=None, color=None, **kwargs
@@ -444,7 +444,7 @@ class ScaleBar:
 
         if hasattr(self, "_lon") and hasattr(self, "_lat"):
             self.set_position()
-            self._m.BM.blit_artists(self._artists.values())
+            self._m.BM.update(artists=self._artists.values())
 
     def _get_base_pts(self, lon, lat, azim, npts=None):
         if npts is None:
@@ -751,7 +751,7 @@ class ScaleBar:
         # self._m.BM.add_artist(self._artists["text"])
         self._m.BM.add_artist(self._artists["patch"], layer=self.layer)
 
-        self._m.BM.blit_artists(self._artists.values())
+        self._m.BM.update(artists=self._artists.values())
         # make sure to update the artists on zoom
         self._decorate_zooms()
 
@@ -982,6 +982,7 @@ class ScaleBar:
                 self.auto_position(self._auto_position)
 
             self.set_position()
+            self._m.BM.update()
             return ret
 
         return newzoom
@@ -1002,6 +1003,8 @@ class ScaleBar:
                 self.auto_position(self._auto_position)
 
             self.set_position()
+            self._m.BM.update()
+
             return ret
 
         return newupdate
@@ -1122,7 +1125,7 @@ class Compass:
         self.layer = layer
 
         self._ignore_invalid_angles = ignore_invalid_angles
-        self._m.BM.update()
+        # self._m.BM.update()
 
         ax2data = self._m.ax.transAxes + self._m.ax.transData.inverted()
 
@@ -1156,7 +1159,7 @@ class Compass:
         self._m.ax.add_artist(self._artist)
         self._m.BM.add_artist(self._artist, layer=self.layer)
 
-        self.set_position(pos)
+        self._set_position(pos)
 
         if pickable:
             if not self._artist.pickable():
@@ -1252,14 +1255,14 @@ class Compass:
         try:
             if x is None or y is None:
                 try:
-                    self.set_position(self._pos)
+                    self._set_position(self._pos)
                     return
                 except Exception:
                     x, y = 0.9, 0.1
-                    self.set_position((x, y), "axis")
+                    self._set_position((x, y), "axis")
                     return
 
-            self.set_position((x, y), "data")
+            self._set_position((x, y), "data")
         except Exception:
             pass
 
@@ -1330,7 +1333,7 @@ class Compass:
                 x, y = self._m.ax.transData.inverted().transform((evt.x, evt.y))
 
             self._update_offset(x, y)
-            self._m.BM.blit_artists(artists=[self._artist])
+            self._m.BM.update(artists=[self._artist])
 
     def _on_scroll(self, event):
         if not self._layer_visible:
@@ -1338,7 +1341,6 @@ class Compass:
 
         if self._check_still_parented() and self._got_artist:
             self.set_scale(max(1, self._scale + event.step))
-            self._m.BM.blit_artists(artists=[self._artist])
 
     def _on_pick(self, evt):
         if not self._layer_visible:
@@ -1492,6 +1494,20 @@ class Compass:
             b = None
         self._artist.set_picker(b)
 
+    def _set_position(self, pos, coords="data"):
+        # Avoid calling BM.update() in here! It results in infinite
+        # recursions on zoom events because the position of the scalebar is
+        # dynamically updated on each re-fetch of the background!
+
+        if coords == "axis":
+            self._ax2data = self._m.ax.transAxes + self._m.ax.transData.inverted()
+            pos = self._ax2data.transform(pos)
+
+        trans = self._get_transform(pos)
+        for c in self._artist.get_children():
+            c.set_transform(trans)
+        self._pos = pos
+
     def set_position(self, pos, coords="data"):
         """
         Set the position of the compass.
@@ -1509,14 +1525,8 @@ class Compass:
 
             The default is "data".
         """
-        if coords == "axis":
-            self._ax2data = self._m.ax.transAxes + self._m.ax.transData.inverted()
-            pos = self._ax2data.transform(pos)
-
-        trans = self._get_transform(pos)
-        for c in self._artist.get_children():
-            c.set_transform(trans)
-        self._pos = pos
+        self._set_position(pos, coords="data")
+        self._m.BM.update(artists=[self._artist])
 
     def get_position(self, coords="data"):
         """
